@@ -103,7 +103,7 @@ def test_array_sep():
 
 
 def test_numpy_floats():
-    import numpy as np
+    np = pytest.importorskip('numpy')
 
     encoder = toml.TomlNumpyEncoder()
     d = {'a': np.array([1, .3], dtype=np.float64)}
@@ -120,7 +120,7 @@ def test_numpy_floats():
 
 
 def test_numpy_ints():
-    import numpy as np
+    np = pytest.importorskip('numpy')
 
     encoder = toml.TomlNumpyEncoder()
     d = {'a': np.array([1, 3], dtype=np.int64)}
@@ -271,3 +271,12 @@ b-comment = "a is 3"
                    encoder=toml.TomlPreserveCommentEncoder())
 
     assert len(s) == len(test_str) and sorted(test_str) == sorted(s)
+
+
+def test_deepcopy_timezone():
+    import copy
+
+    o = toml.loads("dob = 1979-05-24T07:32:00-08:00")
+    o2 = copy.deepcopy(o)
+    assert o2["dob"] == o["dob"]
+    assert o2["dob"] is not o["dob"]
